@@ -1,6 +1,6 @@
 ;;; modus-operandi-theme.el --- Elegant, highly legible theme with a white background -*- lexical-binding:t -*-
 
-;; Copyright (C) 2019-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2019-2025  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -170,10 +170,6 @@ which corresponds to a minimum contrast in relative luminance of
       (bg-region           "#bdbdbd")
       (fg-region           "#000000")
 
-      (bg-char-0 "#7feaff")
-      (bg-char-1 "#ffaaff")
-      (bg-char-2 "#dff000")
-
       (bg-mode-line-active        "#c8c8c8")
       (fg-mode-line-active        "#000000")
       (border-mode-line-active    "#5a5a5a")
@@ -214,13 +210,6 @@ which corresponds to a minimum contrast in relative luminance of
 
       (bg-diff-context    "#f3f3f3")
 
-;;; Paren match
-
-      (bg-paren-match        "#5fcfff")
-      (fg-paren-match        fg-main)
-      (bg-paren-expression   "#efd3f5")
-      (underline-paren-match unspecified)
-
 ;;; Mappings
 
 ;;;; General mappings
@@ -273,6 +262,13 @@ which corresponds to a minimum contrast in relative luminance of
       (type cyan-cooler)
       (variable cyan)
 
+;;;; Paren match
+
+      (bg-paren-match        bg-cyan-subtle)
+      (fg-paren-match        fg-main)
+      (underline-paren-match unspecified)
+      (bg-paren-expression   bg-yellow-nuanced)
+
 ;;;; Accent mappings
 
       (accent-0 blue)
