@@ -1,6 +1,6 @@
 ;;; modus-vivendi-theme.el --- Elegant, highly legible theme with a black background -*- lexical-binding:t -*-
 
-;; Copyright (C) 2019-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2019-2025  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -170,10 +170,6 @@ which corresponds to a minimum contrast in relative luminance of
       (bg-region           "#5a5a5a")
       (fg-region           "#ffffff")
 
-      (bg-char-0 "#0050af")
-      (bg-char-1 "#7f1f7f")
-      (bg-char-2 "#625a00")
-
       (bg-mode-line-active        "#505050")
       (fg-mode-line-active        "#ffffff")
       (border-mode-line-active    "#959595")
@@ -214,13 +210,6 @@ which corresponds to a minimum contrast in relative luminance of
 
       (bg-diff-context    "#1a1a1a")
 
-;;; Paren match
-
-      (bg-paren-match        "#2f7f9f")
-      (fg-paren-match        fg-main)
-      (bg-paren-expression   "#453040")
-      (underline-paren-match unspecified)
-
 ;;; Mappings
 
 ;;;; General mappings
@@ -273,6 +262,13 @@ which corresponds to a minimum contrast in relative luminance of
       (type cyan-cooler)
       (variable cyan)
 
+;;;; Paren match
+
+      (bg-paren-match        bg-cyan-subtle)
+      (fg-paren-match        fg-main)
+      (underline-paren-match unspecified)
+      (bg-paren-expression   bg-yellow-nuanced)
+
 ;;;; Accent mappings
 
       (accent-0 blue-cooler)
